translate.tools.posegment

Package translate :: Package tools :: Module posegment |
[hide private]
[frames] | no frames]

# Module posegment

source code

Segment Gettext PO, XLIFF and TMX localization files at the sentence level.

See: http://translate.sourceforge.net/wiki/toolkit/posegment for examples and usage instructions

Classes | [hide private]
| segment

Functions | [hide private]
segmentfile(inputfile, outputfile, templatefile, sourcelanguage="en", targetlanguage=None, stripspaces=True) reads in inputfile, segments it then, writes to outputfile | source code
main() | source code

Imports: factory, lang_factory